@@ -1,7 +1,19 @@
-from models import DatabaseBind, InstanceBind
+from models import DatabaseBind, InstanceBind, CREATED, CREATING, ERROR
+import logging
+
+logging.basicConfig()
+LOG = logging.getLogger("AclBindApi")
+LOG.setLevel(logging.DEBUG)
 
 def update_bind_status(database, bind_address, bind_status):
 
+    LOG.debug("Update {} bind {} with status {}".format(database, bind_address, bind_status))
+
+    if bind_address == CREATING:
+        bind_address = CREATED
+    else:
+        bind_address = ERROR
+
     bind = DatabaseBind.objects.get(database= database, bind_address= bind_address)
     instances = database.infra.instances.all()
     bind_instances = InstanceBind.objects.filter(instance__in= instances,  bind_address= bind_address)
